# Mangandi - Python Package

>Please note that this project is no longer being maintained. If you are looking for an alternative, it would be advisable because we lack the funds to continue maintaining it. If you wish to make a donation, please visit the
Telegram group [Group](https://t.me/XBOTSUPPORTS).

Welcome to the Mangandi python package repository! 🐍

## Overview
Mangandi is a super cool python package that allows you to easily work with videos and images. It provides powerful tools for image and video manipulation in Python.

## Installation
You can install Mangandi via PyPI. Simply run:

```pip install Mangandi```

## Support
Join our Telegram support group [Support](https://t.me/XBOTSUPPORTS) for any help or queries related to Mangandi.

# Usage 

```

from Mangandi import ImageUploader

k = "/path/to/your/file.jpg"
up = ImageUploader(k)
link = up.upload()
print(f"Image uploaded! {link}")
```

